{% load i18n %}
{% with instance.target as target %}
  <div class="teaser">
    <h2>{{ instance.title }}</h2>
    {% if instance.image %}
      {% if instance.url %}<a href="{{ instance.url }}"{% if target %} target="{{ target }}"{% endif %}>{% endif %}
        <img src="{{ instance.image.url }}" alt="{{ instance.title }}"/>
      {% if instance.url %}</a>{% endif %}
    {% endif %}
    {% if instance.description %}<p>{{ instance.description }}</p>{% endif %}
    {% if instance.url %}
      <a href="{{ instance.url }}"{% if target %} target="{{ target }}"{% endif %}>{% trans "more" %} &#187;</a>
    {% endif %}
  </div>
{% endwith %}
