<figure class="picture {{ instance.align_class }}">{% spaceless %}
  {% if instance.url %}<a href="{{ instance.url }}"{% if instance.in_new_window %} target="_blank"{% endif %}>{% endif %}
  <img src="{{ instance.image.url }}" width="{{ instance.image.width }}" height="{{ instance.image.height }}" alt="" />
  {% if instance.url %}</a>{% endif %}
  {% if instance.caption %}<figcaption>{{ instance.caption }}</figcaption>{% endif %}
{% endspaceless %}</figure>
